//go:build ignore

package main

import (
	"fmt"
	"log"
	"os"
	"text/template"
	"time"
)

const Path = "/usr/shared/dictionary/words"

func main() {
	fmt.Println("Generate")

	f, err := os.Create("internal/dictionary/words.go")
	die(err)
	defer f.Close()

	packageTemplate.Execute(f, struct {
		Timestamp time.Time
		Path      string
		Words     []string
	}{
		Timestamp: time.Now(),
		Path:      Path,
		Words: []string{
			"foo",
			"bar",
			"baz",
		},
	})

}

func die(err error) {
	if err != nil {
		log.Fatal(err)
	}
}

var packageTemplate = template.Must(template.New("").Parse(`// Code generated by go generate; DO NOT EDIT.
// This file was generated by robots at
// {{ .Timestamp }}
// using data from
// {{ .Path }}
package dictionary

var Words = []string{
{{- range .Words }}
	{{ printf "%q" . }},
{{- end }}
}
`))
